@@ -138,6 +138,7 @@ ORBit_setup_debug_flags (void)
 		{ "types",    ORBIT_DEBUG_TYPES },
 		{ "messages", ORBIT_DEBUG_MESSAGES },
 		{ "objects",  ORBIT_DEBUG_OBJECTS },
+		{ "giop",     ORBIT_DEBUG_GIOP },
 	};
 	const char *env_string;
 
@@ -205,55 +206,63 @@ CORBA_ORB_init (int *argc, char **argv,
 }
 
 CORBA_char *
-CORBA_ORB_object_to_string(CORBA_ORB _obj,
-			   const CORBA_Object obj,
-			   CORBA_Environment * ev)
+CORBA_ORB_object_to_string (CORBA_ORB          orb,
+			   const CORBA_Object  obj,
+			   CORBA_Environment  *ev)
 {
-  GIOPSendBuffer *buf;
-  CORBA_octet endianness = GIOP_FLAG_ENDIANNESS;
-  CORBA_char *out;
-  int i, j, k;
+	GIOPSendBuffer *buf;
+	CORBA_octet     endianness = GIOP_FLAG_ENDIANNESS;
+	CORBA_char     *out;
+	int             i, j, k;
 
-  g_return_val_if_fail(ev, NULL);
+	g_return_val_if_fail (ev != NULL, NULL);
 
-  if(!obj || !_obj
-     || ORBIT_ROOT_OBJECT_TYPE(obj) != ORBIT_ROT_OBJREF)
-    {
-      CORBA_exception_set_system(ev,
-				 ex_CORBA_BAD_PARAM,
-				 CORBA_COMPLETED_NO);
-      return NULL;
-    }
+	if(!orb || !obj || ORBIT_ROOT_OBJECT_TYPE (obj) != ORBIT_ROT_OBJREF) {
+		CORBA_exception_set_system (
+				ev, ex_CORBA_BAD_PARAM, CORBA_COMPLETED_NO);
 
-  buf = giop_send_buffer_use(_obj->default_giop_version);
-  buf->header_size = 0;
-  g_assert(buf->num_used == 1);
-  buf->lastptr = NULL;
-  buf->num_used = 0; /* we don't want the header in there */
-  buf->msg.header.message_size = 0;
-  giop_send_buffer_append(buf, &endianness, 1);
-  ORBit_marshal_object(buf, obj);
-  out = CORBA_string_alloc(4 + (buf->msg.header.message_size * 2) + 1);
-
-  strcpy(out, "IOR:");
-  k = 4;
-  for(i = 0; i < buf->num_used; i++)
-    {
-      struct iovec *curvec = &buf->iovecs[i];
-      guchar *ptr = curvec->iov_base;
-
-      for(j = 0; j < curvec->iov_len; j++, ptr++)
-	{
-	  int n1 = (*ptr & 0xF0) >> 4, n2 = (*ptr & 0xF);
-	  out[k++] = num2hexdigit(n1);
-	  out[k++] = num2hexdigit(n2);
+		return NULL;
 	}
-    }
-  out[k++] = '\0';
-  
-  giop_send_buffer_unuse(buf);
 
-  return out;
+	buf = giop_send_buffer_use (orb->default_giop_version);
+
+	g_assert (buf->num_used == 1);
+
+	buf->header_size             = 0;
+	buf->lastptr                 = NULL;
+	buf->num_used                = 0; /* we don't want the header in there */
+	buf->msg.header.message_size = 0;
+
+	giop_send_buffer_append (buf, &endianness, 1);
+
+	ORBit_marshal_object (buf, obj);
+	out = CORBA_string_alloc (4 + (buf->msg.header.message_size * 2) + 1);
+
+	strcpy (out, "IOR:");
+
+	for (i = 0, k = 4; i < buf->num_used; i++) {
+		struct iovec *curvec;
+		guchar       *ptr;
+
+		curvec = &buf->iovecs [i];
+		ptr    = curvec->iov_base;
+
+		for (j = 0; j < curvec->iov_len; j++, ptr++) {
+			int n1, n2;
+
+			n1 = (*ptr & 0xF0) >> 4;
+			n2 = (*ptr & 0xF);
+
+			out [k++] = num2hexdigit (n1);
+			out [k++] = num2hexdigit (n2);
+		}
+	}
+
+	out [k++] = '\0';
+  
+	giop_send_buffer_unuse (buf);
+
+	return out;
 }
 
 CORBA_Object
@@ -338,49 +347,51 @@ CORBA_ORB_create_list (CORBA_ORB          obj,
 }
 
 void
-CORBA_ORB_create_operation_list(CORBA_ORB _obj,
-				const CORBA_OperationDef oper,
-				CORBA_NVList * new_list,
-				CORBA_Environment * ev)
+CORBA_ORB_create_operation_list (CORBA_ORB                 orb,
+				 const CORBA_OperationDef  oper,
+				 CORBA_NVList             *new_list,
+				 CORBA_Environment        *ev)
 {
 }
 
 void
-CORBA_ORB_send_multiple_requests_oneway(CORBA_ORB _obj,
-					const CORBA_RequestSeq * req,
-					CORBA_Environment * ev)
+CORBA_ORB_send_multiple_requests_oneway (CORBA_ORB               orb,
+					 const CORBA_RequestSeq *req,
+					 CORBA_Environment      *ev)
 {
 }
 
 void
-CORBA_ORB_send_multiple_requests_deferred(CORBA_ORB _obj,
-					  const CORBA_RequestSeq *req,
-					  CORBA_Environment * ev)
+CORBA_ORB_send_multiple_requests_deferred (CORBA_ORB               orb,
+					   const CORBA_RequestSeq *req,
+					   CORBA_Environment      *ev)
 {
 }
 
 CORBA_boolean
-CORBA_ORB_poll_next_response(CORBA_ORB _obj,
-			     CORBA_Environment * ev)
+CORBA_ORB_poll_next_response (CORBA_ORB          orb,
+			      CORBA_Environment *ev)
 {
-  return CORBA_FALSE;
+	return CORBA_FALSE;
 }
 
 void
-CORBA_ORB_get_next_response(CORBA_ORB _obj, CORBA_Request * req,
-			    CORBA_Environment * ev)
+CORBA_ORB_get_next_response (CORBA_ORB          orb,
+			     CORBA_Request     *req,
+			     CORBA_Environment *ev)
 {
-  *req = NULL;
+	*req = NULL;
 }
 
 CORBA_boolean
-CORBA_ORB_get_service_information(CORBA_ORB _obj,
-				  const CORBA_ServiceType service_type,
-				  CORBA_ServiceInformation **service_information,
-				  CORBA_Environment * ev)
+CORBA_ORB_get_service_information (CORBA_ORB                  orb,
+				   const CORBA_ServiceType    service_type,
+				   CORBA_ServiceInformation **service_information,
+				   CORBA_Environment         *ev)
 {
-  *service_information = NULL;
-  return CORBA_FALSE;
+	*service_information = NULL;
+
+	return CORBA_FALSE;
 }
 
 struct ORBit_service_list_info {
@@ -459,51 +470,55 @@ CORBA_TypeCode_allocate (void)
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_struct_tc (CORBA_ORB                    _obj,
+CORBA_ORB_create_struct_tc (CORBA_ORB                    orb,
 			    const CORBA_char            *id,
 			    const CORBA_char            *name,
 			    const CORBA_StructMemberSeq *members,
 			    CORBA_Environment           *ev)
 {
-  CORBA_TypeCode tc;
-  int i;
+	CORBA_TypeCode retval;
+	int            i;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc == NULL)
-    goto tc_alloc_failed;
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval)
+		goto tc_alloc_failed;
 
-  tc->subtypes = g_new0(CORBA_TypeCode, members->_length);
-  if(tc->subtypes == NULL)
-    goto subtypes_alloc_failed;
+	retval->subtypes = g_new0 (CORBA_TypeCode, members->_length);
+	if (!retval->subtypes)
+		goto subtypes_alloc_failed;
 
-  tc->subnames = g_new0(char *, members->_length);
-  if(tc->subnames == NULL)
-    goto subnames_alloc_failed;
+	retval->subnames = g_new0 (char *, members->_length);
+	if (!retval->subnames)
+		goto subnames_alloc_failed;
 
-  tc->kind = CORBA_tk_struct;
-  tc->name = g_strdup(name);
-  tc->repo_id = g_strdup(id);
-  tc->sub_parts = members->_length;
-  tc->length = members->_length;
+	retval->kind      = CORBA_tk_struct;
+	retval->name      = g_strdup (name);
+	retval->repo_id   = g_strdup (id);
+	retval->sub_parts = members->_length;
+	retval->length    = members->_length;
 
-  for(i = 0; i<members->_length; i++) {
-    CORBA_StructMember *mem = (CORBA_StructMember *)&(members->_buffer[i]);
+	for(i = 0; i < members->_length; i++) {
+		CORBA_StructMember *member = &members->_buffer [i];
 
-    g_assert(&(mem->type) != NULL);
+		g_assert (&member->type != CORBA_OBJECT_NIL);
 
-    tc->subtypes[i] = ORBit_RootObject_duplicate(mem->type);
-    tc->subnames[i] = g_strdup(mem->name);
-  }
+		retval->subtypes [i] = ORBit_RootObject_duplicate (member->type);
+		retval->subnames [i] = g_strdup (member->name);
+	}
 
-  return(tc);
+	return retval;
 
  subnames_alloc_failed:
-  g_free(tc->subtypes);
+	g_free (retval->subtypes);
+
  subtypes_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return NULL;
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 static void
@@ -532,378 +547,400 @@ copy_case_value (CORBA_long *dest,
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_union_tc (CORBA_ORB                   _obj,
+CORBA_ORB_create_union_tc (CORBA_ORB                   orb,
 			   const CORBA_char           *id,
 			   const CORBA_char           *name,
 			   const CORBA_TypeCode        discriminator_type,
 			   const CORBA_UnionMemberSeq *members,
 			   CORBA_Environment          *ev)
 {
-  CORBA_TypeCode tc;
-  int i;
+	CORBA_TypeCode retval;
+	int            i;
 
-  tc=CORBA_TypeCode_allocate();
+	retval = CORBA_TypeCode_allocate ();
 
-  if(tc == NULL)
-    goto tc_alloc_failed;
+	if (!retval)
+		goto tc_alloc_failed;
 
-  tc->discriminator = ORBit_RootObject_duplicate(discriminator_type);
+	retval->discriminator = ORBit_RootObject_duplicate (discriminator_type);
 		
-  tc->subtypes=g_new0(CORBA_TypeCode, members->_length);
-  if(tc->subtypes==NULL)
-    goto subtypes_alloc_failed;
+	retval->subtypes = g_new0 (CORBA_TypeCode, members->_length);
+	if (!retval)
+		goto subtypes_alloc_failed;
 
-  tc->subnames=g_new0(char *, members->_length);
-  if(tc->subnames==NULL)
-    goto subnames_alloc_failed;
+	retval->subnames = g_new0 (char *, members->_length);
+	if(!retval->subnames)
+		goto subnames_alloc_failed;
 
-  tc->sublabels=g_new0(CORBA_long, members->_length);
-  if(tc->sublabels == NULL)
-    goto sublabels_alloc_failed;
+	retval->sublabels = g_new0 (CORBA_long, members->_length);
+	if (!retval->sublabels)
+		goto sublabels_alloc_failed;
 
-  tc->kind=CORBA_tk_union;
-  tc->name=g_strdup(name);
-  tc->repo_id=g_strdup(id);
-  tc->sub_parts=members->_length;
-  tc->length=members->_length;
-  tc->default_index=-1;
+	retval->kind          = CORBA_tk_union;
+	retval->name          = g_strdup (name);
+	retval->repo_id       = g_strdup (id);
+	retval->sub_parts     = members->_length;
+	retval->length        = members->_length;
+	retval->default_index = -1;
 
-  for(i=0;i<members->_length;i++) {
-    CORBA_UnionMember *mem=(CORBA_UnionMember *)&(members->_buffer[i]);
+	for (i = 0; i < members->_length; i++) {
+		CORBA_UnionMember *member = &members->_buffer [i];
 
-    g_assert(&(mem->label)!=NULL);
-    copy_case_value (&tc->sublabels [i], &mem->label);
-    g_assert(&(mem->type)!=NULL);
-    tc->subtypes[i] = ORBit_RootObject_duplicate(mem->type);
-    tc->subnames[i]=g_strdup(mem->name);
+		g_assert (member->type != CORBA_OBJECT_NIL);
 
-    if(mem->label._type->kind==CORBA_tk_octet) {
-      tc->default_index=i;
-    }
-  }
+		copy_case_value (&retval->sublabels [i], &member->label);
 
-  return(tc);
+		retval->subtypes [i] = ORBit_RootObject_duplicate (member->type);
+		retval->subnames [i] = g_strdup (member->name);
+
+		if (member->label._type->kind == CORBA_tk_octet)
+			retval->default_index = i;
+	}
+
+	return retval;
 
  sublabels_alloc_failed:
-  g_free(tc->sublabels);
+	g_free (retval->sublabels);
+
  subnames_alloc_failed:
-  g_free(tc->subtypes);
+	g_free (retval->subtypes);
+
  subtypes_alloc_failed:
-  ORBit_free(tc->discriminator);
-  ORBit_RootObject_release(tc);
+	ORBit_free (retval->discriminator);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return NULL;
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_enum_tc (CORBA_ORB                  _obj,
+CORBA_ORB_create_enum_tc (CORBA_ORB                  orb,
 			  const CORBA_char          *id,
 			  const CORBA_char          *name,
 			  const CORBA_EnumMemberSeq *members,
 			  CORBA_Environment         *ev)
 {
-  CORBA_TypeCode tc;
-  int i;
+	CORBA_TypeCode retval;
+	int            i;
 
-  tc = CORBA_TypeCode_allocate();
-  if(tc == NULL)
-    goto tc_alloc_failed;
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval)
+		goto tc_alloc_failed;
 
-  tc->subnames=g_new0(char *, members->_length);
-  if(tc->subnames==NULL)
-    goto subnames_alloc_failed;
+	retval->subnames=g_new0 (char *, members->_length);
+	if (!retval->subnames)
+		goto subnames_alloc_failed;
 
-  tc->kind = CORBA_tk_enum;
-  tc->name = g_strdup(name);
-  tc->repo_id = g_strdup(id);
-  tc->sub_parts = members->_length;
-  tc->length = members->_length;
+	retval->kind      = CORBA_tk_enum;
+	retval->name      = g_strdup (name);
+	retval->repo_id   = g_strdup (id);
+	retval->sub_parts = members->_length;
+	retval->length    = members->_length;
 
-  for(i=0;i<members->_length;i++)
-    tc->subnames[i]=g_strdup(members->_buffer[i]);
+	for (i = 0; i < members->_length; i++)
+		retval->subnames [i] = g_strdup (members->_buffer [i]);
 
-  return(tc);
+	return retval;
 
  subnames_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return(NULL);
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_alias_tc (CORBA_ORB                 _obj,
-			   const CORBA_char         *id,
-			   const CORBA_char         *name,
-			   const CORBA_TypeCode      original_type,
-			   CORBA_Environment        *ev)
+CORBA_ORB_create_alias_tc (CORBA_ORB             orb,
+			   const CORBA_char     *id,
+			   const CORBA_char     *name,
+			   const CORBA_TypeCode  original_type,
+			   CORBA_Environment    *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-  tc = CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    goto tc_alloc_failed;
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval)
+		goto tc_alloc_failed;
 	
-	/* Can't use chunks here, because it's sometimes an array. Doh! */
-  tc->subtypes=g_new0(CORBA_TypeCode, 1);
-  if(tc->subtypes==NULL)
-    goto subtypes_alloc_failed;
+	retval->subtypes = g_new0 (CORBA_TypeCode, 1);
+	if (!retval->subtypes)
+		goto subtypes_alloc_failed;
 
-  tc->kind=CORBA_tk_alias;
-  tc->name=g_strdup(name);
-  tc->repo_id=g_strdup(id);
-  tc->sub_parts=1;
-  tc->length=1;
+	retval->kind      = CORBA_tk_alias;
+	retval->name      = g_strdup (name);
+	retval->repo_id   = g_strdup (id);
+	retval->sub_parts = 1;
+	retval->length    = 1;
 
-  tc->subtypes[0] = ORBit_RootObject_duplicate(original_type);
+	retval->subtypes [0] = ORBit_RootObject_duplicate (original_type);
+
+	return retval;
 
-  return(tc);
  subtypes_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return NULL;
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_exception_tc (CORBA_ORB                    _obj,
+CORBA_ORB_create_exception_tc (CORBA_ORB                    orb,
 			       const CORBA_char            *id,
 			       const CORBA_char            *name,
 			       const CORBA_StructMemberSeq *members,
 			       CORBA_Environment           *ev)
 {
-  CORBA_TypeCode tc;
-  int i;
+	CORBA_TypeCode retval;
+	int            i;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    goto tc_alloc_failed;
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval)
+		goto tc_alloc_failed;
 
-  if (members->_length == 0)
-    {
-      tc->subtypes = NULL;
-      tc->subnames = NULL;
-    }
-  else
-    {
-      tc->subtypes=g_new0(CORBA_TypeCode, members->_length);
-      if(tc->subtypes==NULL)
-	goto subtypes_alloc_failed;
+	if (members->_length) {
+		retval->subtypes = g_new0 (CORBA_TypeCode, members->_length);
+		if (!retval->subtypes)
+			goto subtypes_alloc_failed;
 
-      tc->subnames=g_new0(char *, members->_length);
-      if(tc->subnames==NULL)
-	goto subnames_alloc_failed;
-    }
+		retval->subnames = g_new0 (char *, members->_length);
+		if (!retval->subnames)
+			goto subnames_alloc_failed;
+	}
 
-  tc->kind=CORBA_tk_except;
-  tc->name=g_strdup(name);
-  tc->repo_id=g_strdup(id);
-  tc->sub_parts=members->_length;
-  tc->length=members->_length;
+	retval->kind      = CORBA_tk_except;
+	retval->name      = g_strdup (name);
+	retval->repo_id   = g_strdup (id);
+	retval->sub_parts = members->_length;
+	retval->length    = members->_length;
 
-  for(i=0;i<members->_length;i++) {
-    CORBA_StructMember *mem=(CORBA_StructMember *)&(members->_buffer[i]);
+	for (i = 0; i < members->_length; i++) {
+		CORBA_StructMember *member = &members->_buffer [i];
 
-    g_assert(mem->type != NULL);
-    tc->subtypes[i] = ORBit_RootObject_duplicate(mem->type);
-    tc->subnames[i]=g_strdup(mem->name);
-  }
+		g_assert (member->type != CORBA_OBJECT_NIL);
 
-  return(tc);
+		retval->subtypes [i] = ORBit_RootObject_duplicate (member->type);
+		retval->subnames [i] = g_strdup (member->name);
+	}
+
+	return retval;
 
  subnames_alloc_failed:
-  g_free(tc->subtypes);
+	g_free (retval->subtypes);
+
  subtypes_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return(NULL);
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_interface_tc (CORBA_ORB                 _obj,
+CORBA_ORB_create_interface_tc (CORBA_ORB                 orb,
 			       const CORBA_char         *id,
 			       const CORBA_char         *name,
 			       CORBA_Environment        *ev)
 {
-	CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-	tc=CORBA_TypeCode_allocate();
-	if(tc==NULL) {
-		CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY,
-					   CORBA_COMPLETED_NO);
-		return(NULL);
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval) {
+		CORBA_exception_set_system (
+				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+		return CORBA_OBJECT_NIL;
 	}
 
-	tc->kind=CORBA_tk_objref;
-	tc->name=g_strdup(name);
-	tc->repo_id=g_strdup(id);
+	retval->kind    = CORBA_tk_objref;
+	retval->name    = g_strdup (name);
+	retval->repo_id = g_strdup (id);
 
-	return(tc);
+	return retval;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_string_tc(CORBA_ORB _obj,
-			   const CORBA_unsigned_long bound,
-			   CORBA_Environment * ev)
+CORBA_ORB_create_string_tc (CORBA_ORB                  orb,
+			    const CORBA_unsigned_long  bound,
+			    CORBA_Environment         *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    {
-      CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-      return(NULL);
-    }
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval) {
+		CORBA_exception_set_system (
+				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
 
-  tc->kind=CORBA_tk_string;
-  tc->length=bound;
+		return CORBA_OBJECT_NIL;
+	}
 
-  return(tc);
+	retval->kind   = CORBA_tk_string;
+	retval->length = bound;
+
+	return retval;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_wstring_tc(CORBA_ORB _obj,
-			    const CORBA_unsigned_long bound,
-			    CORBA_Environment * ev)
+CORBA_ORB_create_wstring_tc (CORBA_ORB                  orb,
+			     const CORBA_unsigned_long  bound,
+			     CORBA_Environment         *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    {
-      CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-      return(NULL);
-    }
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval) {
+		CORBA_exception_set_system (
+				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
 
-  tc->kind=CORBA_tk_wstring;
-  tc->length=bound;
+		return CORBA_OBJECT_NIL;
+	}
 
-  return(tc);
+	retval->kind   = CORBA_tk_wstring;
+	retval->length = bound;
+
+	return retval;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_fixed_tc(CORBA_ORB _obj,
-			  const CORBA_unsigned_short digits,
-			  const CORBA_short scale,
-			  CORBA_Environment * ev)
+CORBA_ORB_create_fixed_tc (CORBA_ORB                   orb,
+			   const CORBA_unsigned_short  digits,
+			   const CORBA_short           scale,
+			   CORBA_Environment          *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    {
-      CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-      return(NULL);
-    }
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval) {
+		CORBA_exception_set_system (
+				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
 
-  tc->kind=CORBA_tk_fixed;
-  tc->digits=digits;
-  tc->scale=scale;
+		return CORBA_OBJECT_NIL;
+	}
 
-  return(tc);
+	retval->kind   = CORBA_tk_fixed;
+	retval->digits = digits;
+	retval->scale  = scale;
+
+	return retval;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_sequence_tc(CORBA_ORB _obj,
-			     const CORBA_unsigned_long
-			     bound,
-			     const CORBA_TypeCode
-			     element_type,
-			     CORBA_Environment * ev)
+CORBA_ORB_create_sequence_tc (CORBA_ORB                  orb,
+			      const CORBA_unsigned_long  bound,
+			      const CORBA_TypeCode       element_type,
+			      CORBA_Environment         *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    goto tc_alloc_failed;
+	retval = CORBA_TypeCode_allocate ();
+	if (!retval)
+		goto tc_alloc_failed;
 
-  tc->subtypes=g_new0(CORBA_TypeCode, 1);
-  if(tc->subtypes==NULL)
-    goto subtypes_alloc_failed;
+	retval->subtypes = g_new0 (CORBA_TypeCode, 1);
+	if (!retval->subtypes)
+		goto subtypes_alloc_failed;
 
-  tc->kind=CORBA_tk_sequence;
-  tc->sub_parts=1;
-  tc->length=bound;
+	retval->kind      = CORBA_tk_sequence;
+	retval->sub_parts = 1;
+	retval->length    = bound;
 
-  tc->subtypes[0] = ORBit_RootObject_duplicate(element_type);
+	retval->subtypes [0] = ORBit_RootObject_duplicate (element_type);
 
-  return(tc);
+	return retval;
 
  subtypes_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return(NULL);
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_recursive_sequence_tc(CORBA_ORB _obj,
-				       const CORBA_unsigned_long bound,
-				       const CORBA_unsigned_long offset,
-				       CORBA_Environment *ev)
+CORBA_ORB_create_recursive_sequence_tc (CORBA_ORB                  orb,
+					const CORBA_unsigned_long  bound,
+					const CORBA_unsigned_long  offset,
+					CORBA_Environment         *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode retval;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    goto tc_alloc_failed;
+	retval=CORBA_TypeCode_allocate ();
+	if (retval)
+		goto tc_alloc_failed;
 
-  tc->subtypes=g_new0(CORBA_TypeCode, 1);
-  if(tc->subtypes==NULL)
-    goto subtypes_alloc_failed;
+	retval->subtypes = g_new0 (CORBA_TypeCode, 1);
+	if (!retval->subtypes)
+		goto subtypes_alloc_failed;
 
-  tc->kind=CORBA_tk_sequence;
-  tc->sub_parts=1;
-  tc->length=bound;
+	retval->kind      = CORBA_tk_sequence;
+	retval->sub_parts = 1;
+	retval->length    = bound;
 
-  tc->subtypes[0] = CORBA_TypeCode_allocate();
-  tc->subtypes[0]->kind=CORBA_tk_recursive;
-  tc->subtypes[0]->recurse_depth=offset;
+	retval->subtypes [0] = CORBA_TypeCode_allocate ();
 
-  return(tc);
+	retval->subtypes [0]->kind          = CORBA_tk_recursive;
+	retval->subtypes [0]->recurse_depth = offset;
+
+	return retval;
 
  subtypes_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (retval);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return(NULL);
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_array_tc(CORBA_ORB _obj,
-			  const CORBA_unsigned_long length,
-			  const CORBA_TypeCode element_type,
-			  CORBA_Environment * ev)
+CORBA_ORB_create_array_tc (CORBA_ORB                  orb,
+			   const CORBA_unsigned_long  length,
+			   const CORBA_TypeCode       element_type,
+			   CORBA_Environment         *ev)
 {
-  CORBA_TypeCode tc;
+	CORBA_TypeCode tc;
 
-  tc=CORBA_TypeCode_allocate();
-  if(tc==NULL)
-    goto tc_alloc_failed;
+	tc = CORBA_TypeCode_allocate ();
+	if (!tc)
+		goto tc_alloc_failed;
 
-  tc->subtypes=g_new0(CORBA_TypeCode, 1);
-  if(tc->subtypes==NULL)
-    goto subtypes_alloc_failed;
+	tc->subtypes = g_new0 (CORBA_TypeCode, 1);
+	if (!tc->subtypes)
+		goto subtypes_alloc_failed;
 
-  tc->kind=CORBA_tk_array;
-  tc->sub_parts=1;
-  tc->length=length;
+	tc->kind      = CORBA_tk_array;
+	tc->sub_parts = 1;
+	tc->length    = length;
 
-  tc->subtypes[0] = ORBit_RootObject_duplicate(element_type);
+	tc->subtypes [0] = ORBit_RootObject_duplicate (element_type);
 
-  return(tc);
+	return (tc);
 
  subtypes_alloc_failed:
-  ORBit_RootObject_release(tc);
+	ORBit_RootObject_release (tc);
+
  tc_alloc_failed:
-  CORBA_exception_set_system(ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
-  return(NULL);
+	CORBA_exception_set_system (
+			ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
+
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_value_tc (CORBA_ORB                   obj,
+CORBA_ORB_create_value_tc (CORBA_ORB                   orb,
 			   const CORBA_char           *id,
 			   const CORBA_char           *name,
 			   const CORBA_ValueModifier   type_modifier,
@@ -911,54 +948,54 @@ CORBA_ORB_create_value_tc (CORBA_ORB                   obj,
 			   const CORBA_ValueMemberSeq *members,
 			   CORBA_Environment          *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_value_box_tc (CORBA_ORB            obj,
-			       const CORBA_char    *id,
-			       const CORBA_char    *name,
-			       const CORBA_TypeCode boxed_type,
-			       CORBA_Environment   *ev)
+CORBA_ORB_create_value_box_tc (CORBA_ORB             orb,
+			       const CORBA_char     *id,
+			       const CORBA_char     *name,
+			       const CORBA_TypeCode  boxed_type,
+			       CORBA_Environment    *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_native_tc (CORBA_ORB          obj,
+CORBA_ORB_create_native_tc (CORBA_ORB          orb,
 			    const CORBA_char  *id,
 			    const CORBA_char  *name,
 			    CORBA_Environment *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_recursive_tc (CORBA_ORB          obj,
+CORBA_ORB_create_recursive_tc (CORBA_ORB          orb,
 			       const CORBA_char  *id,
 			       CORBA_Environment *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_TypeCode
-CORBA_ORB_create_abstract_interface_tc (CORBA_ORB          obj,
+CORBA_ORB_create_abstract_interface_tc (CORBA_ORB          orb,
 				        const CORBA_char  *id,
 				        const CORBA_char  *name,
 				        CORBA_Environment *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_boolean
-CORBA_ORB_work_pending (CORBA_ORB          obj,
+CORBA_ORB_work_pending (CORBA_ORB          orb,
 			CORBA_Environment *ev)
 {
-  return linc_main_pending ();
+	return linc_main_pending ();
 }
 
 void
-CORBA_ORB_perform_work (CORBA_ORB          obj,
+CORBA_ORB_perform_work (CORBA_ORB          orb,
 			CORBA_Environment *ev)
 {
 	linc_main_iteration (FALSE);
@@ -1074,36 +1111,36 @@ CORBA_ORB_destroy (CORBA_ORB          orb,
 }
 
 CORBA_Policy
-CORBA_ORB_create_policy(CORBA_ORB _obj,
-			const CORBA_PolicyType type,
-			const CORBA_any * val,
-			CORBA_Environment * ev)
+CORBA_ORB_create_policy (CORBA_ORB               orb,
+			 const CORBA_PolicyType  type,
+			 const CORBA_any        *val,
+			 CORBA_Environment      *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 CORBA_ValueFactory
-CORBA_ORB_register_value_factory (CORBA_ORB                 _obj,
+CORBA_ORB_register_value_factory (CORBA_ORB                 orb,
 				  const CORBA_char         *id,
 				  const CORBA_ValueFactory  factory,
 				  CORBA_Environment        *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 void
-CORBA_ORB_unregister_value_factory (CORBA_ORB          _obj,
+CORBA_ORB_unregister_value_factory (CORBA_ORB          orb,
 				    const CORBA_char  *id,
 				    CORBA_Environment *ev)
 {
 }
 
 CORBA_ValueFactory
-CORBA_ORB_lookup_value_factory (CORBA_ORB          _obj,
+CORBA_ORB_lookup_value_factory (CORBA_ORB          orb,
 			        const CORBA_char  *id,
 			        CORBA_Environment *ev)
 {
-  return CORBA_OBJECT_NIL;
+	return CORBA_OBJECT_NIL;
 }
 
 void
@@ -1123,10 +1160,12 @@ ORBit_set_initial_reference (CORBA_ORB  orb,
 }
 
 void
-ORBit_ORB_forw_bind (CORBA_ORB orb, CORBA_sequence_CORBA_octet *okey,
-		     CORBA_Object oref, CORBA_Environment *ev)
+ORBit_ORB_forw_bind (CORBA_ORB                   orb,
+		     CORBA_sequence_CORBA_octet *objkey,
+		     CORBA_Object                obj,
+		     CORBA_Environment          *ev)
 {
-	g_warning("ORBit_ORB_forw_bind NYI");
+	g_warning ("ORBit_ORB_forw_bind NYI");
 }
 
 gboolean
@@ -1161,4 +1200,3 @@ static ORBit_option orbit_supported_options[] = {
 	{"ORBDebugFlags",   ORBIT_OPTION_STRING,  &orbit_debug_options},
 	{NULL,              0,                    NULL},
 };
-
